"""
web2ldap plugin classes for schema elements defined in RFC2307

$Id: nis.py,v 1.2 2008/08/26 14:23:49 michael Exp $
"""

import re,pyweblib.forms

from w2lapp.schema.syntaxes import SelectList,IA5String,IntegerRange,DaysSinceEpoch,syntax_registry


class RFC2307BootParameter(IA5String):
  oid = '1.3.6.1.1.1.0.1'
  desc = 'RFC2307 Boot Parameter'
  reObj=None # just a stub, should be made stricter
  

class RFC2307NISNetgroupTriple(IA5String):
  oid = '1.3.6.1.1.1.0.0'
  desc = 'RFC2307 NIS Netgroup Triple'
  reObj=re.compile('^\([a-z0-9.-]*,[a-z0-9.-]*,[a-z0-9.-]*\)$')


class UidNumber(IntegerRange):
  oid = 'UidNumber-oid'
  desc = 'Numerical user ID for Posix systems'
  minValue = 0
  maxValue = 4294967295L


class Shell(SelectList):
  oid = 'Shell-oid'
  desc = 'Shell for user of Posix systems'

  attr_value_dict = {
    '':'',
    '/bin/bash':'Bourne-Again SHell /bin/bash',
    '/bin/csh':'/bin/csh',
    '/bin/tcsh':'/bin/tcsh',
    '/bin/ksh':'Korn shell /bin/ksh',
    '/bin/passwd':'Password change /bin/passwd',
    '/bin/true':'/bin/true',
    '/bin/false':'/bin/false',
    '/usr/bin/bash':'Bourne-Again SHell /usr/bin/bash',
    '/usr/bin/csh':'/usr/bin/csh',
    '/usr/bin/tcsh':'/usr/bin/csh',
    '/usr/bin/ksh':'Korn shell /usr/bin/ksh',
  }


# Register all syntax classes in this module
for name in dir():
  syntax_registry.registerSyntaxClass(eval(name))

syntax_registry.registerAttrType(
  UidNumber.oid,[
    '1.3.6.1.1.1.1.0', # uidNumber
  ]
)

syntax_registry.registerAttrType(
  Shell.oid,[
    '1.3.6.1.1.1.1.4', # loginShell
  ]
)


syntax_registry.registerAttrType(
  DaysSinceEpoch.oid,[
    '1.3.6.1.1.1.1.10', # shadowExpire
    '1.3.6.1.1.1.1.5', # shadowLastChange
  ]
)
